
Security settings in your development frameworks
-------

**Description:**

Whenever certain security settings in your application frameworks 
(e.g., Struts, Spring, ASP.NET) and libraries are not set to secure values this could lead 
to vulnerabilities in your application which an attacker could exploit.



**Solution:**

Make sure al your security settings in your development framework are set to secure values. 
This can be checked by using hardening guides.
	
